@@ -44,8 +44,11 @@ typedef struct {
 
 	char *       (*get_authorization)    (SoupAuth      *auth,
 					      SoupMessage   *msg);
+
+	gboolean     (*is_ready)             (SoupAuth      *auth,
+					      SoupMessage   *msg);
+
 	/* Padding for future expansion */
-	void (*_libsoup_reserved1) (void);
 	void (*_libsoup_reserved2) (void);
 	void (*_libsoup_reserved3) (void);
 	void (*_libsoup_reserved4) (void);
@@ -57,41 +60,60 @@ typedef struct {
 #define SOUP_AUTH_IS_FOR_PROXY     "is-for-proxy"
 #define SOUP_AUTH_IS_AUTHENTICATED "is-authenticated"
 
+SOUP_AVAILABLE_IN_2_4
 GType       soup_auth_get_type              (void);
 
+SOUP_AVAILABLE_IN_2_4
 SoupAuth   *soup_auth_new                   (GType          type,
 					     SoupMessage   *msg,
 					     const char    *auth_header);
+SOUP_AVAILABLE_IN_2_4
 gboolean    soup_auth_update                (SoupAuth      *auth,
 					     SoupMessage   *msg,
 					     const char    *auth_header);
 
+SOUP_AVAILABLE_IN_2_4
 gboolean    soup_auth_is_for_proxy          (SoupAuth      *auth);
+SOUP_AVAILABLE_IN_2_4
 const char *soup_auth_get_scheme_name       (SoupAuth      *auth);
+SOUP_AVAILABLE_IN_2_4
 const char *soup_auth_get_host              (SoupAuth      *auth);
+SOUP_AVAILABLE_IN_2_4
 const char *soup_auth_get_realm             (SoupAuth      *auth);
+SOUP_AVAILABLE_IN_2_4
 char       *soup_auth_get_info              (SoupAuth      *auth);
 
+SOUP_AVAILABLE_IN_2_4
 void        soup_auth_authenticate          (SoupAuth      *auth,
 					     const char    *username,
 					     const char    *password);
+SOUP_AVAILABLE_IN_2_4
 gboolean    soup_auth_is_authenticated      (SoupAuth      *auth);
+SOUP_AVAILABLE_IN_2_42
+gboolean    soup_auth_is_ready              (SoupAuth      *auth,
+					     SoupMessage   *msg);
 
+SOUP_AVAILABLE_IN_2_4
 char       *soup_auth_get_authorization     (SoupAuth      *auth, 
 					     SoupMessage   *msg);
 
+SOUP_AVAILABLE_IN_2_4
 GSList     *soup_auth_get_protection_space  (SoupAuth      *auth,
 					     SoupURI       *source_uri);
+SOUP_AVAILABLE_IN_2_4
 void        soup_auth_free_protection_space (SoupAuth      *auth,
 					     GSList        *space);
 
 /* The actual auth types, which can be added/removed as features */
 
 #define SOUP_TYPE_AUTH_BASIC  (soup_auth_basic_get_type ())
+SOUP_AVAILABLE_IN_2_4
 GType soup_auth_basic_get_type  (void);
 #define SOUP_TYPE_AUTH_DIGEST (soup_auth_digest_get_type ())
+SOUP_AVAILABLE_IN_2_4
 GType soup_auth_digest_get_type (void);
 #define SOUP_TYPE_AUTH_NTLM   (soup_auth_ntlm_get_type ())
+SOUP_AVAILABLE_IN_2_4
 GType soup_auth_ntlm_get_type   (void);
 
 /* Deprecated SoupPasswordManager-related APIs: all are now no-ops */
