@@ -5,6 +5,10 @@
  * Copyright (C) 2000-2003, Ximian, Inc.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 
 #include "soup-misc.h"
